==> streamlit-d3-network-component-0.0.6.tar.gz: streamlit-d3-network-component-0.0.6/streamlit_d3_network_component/__init__.py <==
import os

import streamlit.components.v1 as components
import json

# Create a _RELEASE constant. We'll set this to False while we're developing
# the component, and True when we're ready to package and distribute it.
# (This is, of course, optional - there are innumerable ways to manage your
# release process.)
_RELEASE = True

# Declare a Streamlit component. `declare_component` returns a function
# that is used to create instances of the component. We're naming this
# function "_component_func", with an underscore prefix, because we don't want
# to expose it directly to users. Instead, we will create a custom wrapper
# function, below, that will serve as our component's public API.

# It's worth noting that this call to `declare_component` is the
# *only thing* you need to do to create the binding between Streamlit and
# your component frontend. Everything else we do in this file is simply a
# best practice.

if not _RELEASE:
    _d3net = components.declare_component('streamlit-network-d3',
                                         url='http://localhost:3000/')
else:
    # When we're distributing a production version of the component, we'll
    # replace the `url` param with `path`, and point it to the component's
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _d3net = components.declare_component("streamlit-network-d3", path=build_dir)


# Create a wrapper function for the component. This is an optional
# best practice - we could simply expose the component function returned by
# `declare_component` and call it done. The wrapper allows us to customize
# our component's API: we can pre-process its input args, post-process its
# output value, and add a docstring for users.
def d3net(nodes, links, key=None):
    """Create a new instance of "my_component".

    Parameters
    ----------
    nodes: List[Dict]
        Nodes to depict. Every node has name, kind and id
    links: List[Dict]
        Edges unite together 2 different nodes. Every edge has source and target values.
    key: str or None
        An optional key that uniquely identifies this component. If this is
        None, and the component's arguments are changed, the component will
        be re-mounted in the Streamlit frontend and lose its current state.

    Returns
    -------
    None

    """
    # Call through to our private component function. Arguments we pass here
    # will be sent to the frontend, where they'll be available in an "args"
    # dictionary.
    #
    # "default" is a special argument that specifies the initial return
    # value of the component before the user has interacted with it.
    component_value = _d3net(nodes=nodes, links=links, key=key, default=0)

    # We could modify the value returned from the component if we wanted.
    # There's no need to do this in our simple example - but it's an option.
    return component_value


# Add some test code to play with the component while it's in development.
# During development, we can run this just as we would any other Streamlit
# app: `$ streamlit run my_component/__init__.py`
if not _RELEASE:
    from pathlib import Path
    import streamlit as st

    st.set_page_config(layout="wide")
    st.subheader("Pathway")

    with open(Path(__file__).parent.joinpath('frontend/src/data/data.json'), 'r') as f:
        data_df = json.load(f)
        d3net(nodes=data_df['nodes'], links=data_df['links'])

==> streamlit-d3-network-component-0.0.8.tar.gz: streamlit-d3-network-component-0.0.8/streamlit_d3_network_component/__init__.py <==
import os
from pathlib import Path

import streamlit.components.v1 as components
import json

# Create a _RELEASE constant. We'll set this to False while we're developing
# the component, and True when we're ready to package and distribute it.
# (This is, of course, optional - there are innumerable ways to manage your
# release process.)
_RELEASE = True

# Declare a Streamlit component. `declare_component` returns a function
# that is used to create instances of the component. We're naming this
# function "_component_func", with an underscore prefix, because we don't want
# to expose it directly to users. Instead, we will create a custom wrapper
# function, below, that will serve as our component's public API.

# It's worth noting that this call to `declare_component` is the
# *only thing* you need to do to create the binding between Streamlit and
# your component frontend. Everything else we do in this file is simply a
# best practice.

if not _RELEASE:
    _d3net = components.declare_component('streamlit_d3_network_component',
                                         url='http://localhost:3000/')
else:
    # When we're distributing a production version of the component, we'll
    # replace the `url` param with `path`, and point it to the component's
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _d3net = components.declare_component("streamlit_d3_network_component", path=build_dir)


# Create a wrapper function for the component. This is an optional
# best practice - we could simply expose the component function returned by
# `declare_component` and call it done. The wrapper allows us to customize
# our component's API: we can pre-process its input args, post-process its
# output value, and add a docstring for users.
def d3net(nodes, links, key=None):
    """Create a new instance of "my_component".

    Parameters
    ----------
    nodes: List[Dict]
        Nodes to depict. Every node has name, kind and id
    links: List[Dict]
        Edges unite together 2 different nodes. Every edge has source and target values.
    key: str or None
        An optional key that uniquely identifies this component. If this is
        None, and the component's arguments are changed, the component will
        be re-mounted in the Streamlit frontend and lose its current state.

    Returns
    -------
    None

    """
    # Call through to our private component function. Arguments we pass here
    # will be sent to the frontend, where they'll be available in an "args"
    # dictionary.
    #
    # "default" is a special argument that specifies the initial return
    # value of the component before the user has interacted with it.
    component_value = _d3net(nodes=nodes, links=links, key=key, default=0)

    # We could modify the value returned from the component if we wanted.
    # There's no need to do this in our simple example - but it's an option.
    return component_value


# Add some test code to play with the component while it's in development.
# During development, we can run this just as we would any other Streamlit
# app: `$ streamlit run my_component/__init__.py`
if not _RELEASE:
    import streamlit as st

    st.set_page_config(layout="wide")
    st.subheader("Pathway")

    with open(Path(__file__).parent.joinpath('frontend/src/data/data.json'), 'r') as f:
        data_df = json.load(f)
        d3net(nodes=data_df['nodes'], links=data_df['links'])
